django_dicom.reader.code_strings package — django_dicom 0.1.0 documentation

# django_dicom.reader.code_strings package

## Module contents

DICOM data elements with the Code String (CS) value-representation (VRs), represented as Enums.

## Submodules

## django_dicom.reader.code_strings.modality module

class `django_dicom.reader.code_strings.modality.` `Modality`

  Bases: `django_dicom.models.choice_enum.ChoiceEnum`

  Represents the Modality attribute.

  `AR` = 'Autorefraction'
  `ASMT` = 'Content Assessment Results'
  `AU` = 'Audio'
  `BDUS` = 'Bone Densitometry (ultrasound)'
  `BI` = 'Biomagnetic imaging'
  `BMD` = 'Bone Densitometry (X-Ray)'
  `CR` = 'Computed Radiography'
  `CT` = 'Computed Tomography'
  `CTPROTOCOL` = 'CT Protocol (Performed)'
  `DG` = 'Diaphanography'
  `DOC` = 'Document'
  `DX` = 'Digital Radiography'
  `ECG` = 'Electrocardiography'
  `EDS` = 'Endoscopy'
  `EPS` = 'Cardiac Electrophysiology'
  `FID` = 'Fiducials'
  `GM` = 'General Microscopy'
  `HC` = 'Hard Copy'
  `HD` = 'Hemodynamic Waveform'
  `IO` = 'Intra-Oral Radiography'
  `IOL` = 'Intraocular Lens Data'
  `IVOCT` = 'Intravascular Optical Coherence Tomography'
  `IVUS` = 'Intravascular Ultrasound'
  `KER` = 'Keratometry'
  `KO` = 'Key Object Selection'
  `LEN` = 'Lensometry'
  `LS` = 'Laser surface scan'
  `M3D` = 'Model for 3D Manufacturing'
  `MG` = 'Mammography'
  `MR` = 'Magnetic Resonance'
  `NM` = 'Nuclear Medicine'
  `OAM` = 'Ophthalmic Axial Measurements'
  `OCT` = 'Optical Coherence Tomography (non-Ophthalmic)'
  `OP` = 'Ophthalmic Photography'
  `OPM` = 'Ophthalmic Mapping'
  `OPT` = 'Ophthalmic Tomography'
  `OPTBSV` = 'Ophthalmic Tomography B-scan Volume Analysis'
  `OPTENF` = 'Ophthalmic Tomography En Face'
  `OPV` = 'Ophthalmic Visual Field'
  `OSS` = 'Optical Surface Scan'
  `OT` = 'Other'
  `PLAN` = 'Plan'
  `PR` = 'Presentation State'
  `PT` = 'Positron emission tomography (PET)'
  `PX` = 'Panoramic X-Ray'
  `REG` = 'Registration'
  `RESP` = 'Respiratory Waveform'
  `RF` = 'Radio Fluoroscopy'
  `RG` = 'Radiographic imaging (conventional film/screen)'
  `RTDOSE` = 'Radiotherapy Dose'
  `RTIMAGE` = 'Radiotherapy Image'
  `RTPLAN` = 'Radiotherapy Plan'
  `RTRECORD` = 'RT Treatment Record'
  `RTSTRUCT` = 'Radiotherapy Structure Set'
  `RWV` = 'Real World Value Map'
  `SEG` = 'Segmentation'
  `SM` = 'Slide Microscopy'
  `SMR` = 'Stereometric Relationship'
  `SR` = 'SR Document'
  `SRF` = 'Subjective Refraction'
  `STAIN` = 'Automated Slide Stainer'
  `TG` = 'Thermography'
  `US` = 'Ultrasound'
  `VA` = 'Visual Acuity'
  `XA` = 'X-Ray Angiography'
  `XC` = 'External-camera Photography'

## django_dicom.reader.code_strings.patient_position module

class `django_dicom.reader.code_strings.patient_position.` `PatientPosition`

  Bases: `django_dicom.models.choice_enum.ChoiceEnum`

  Represents the Patient Position attribute.

  `AFDL` = 'Anterior First-Decubitus Left'
  `AFDR` = 'Anterior First-Decubitus Right'
  `FFDL` = 'Feet First-Decubitus Left'
  `FFDR` = 'Feet First-Decubitus Right'
  `FFP` = 'Feet First-Prone'
  `FFS` = 'Feet First-Supine'
  `HFDL` = 'Head First-Decubitus Left'
  `HFDR` = 'Head First-Decubitus Right'
  `HFP` = 'Head First-Prone'
  `HFS` = 'Head First-Supine'
  `LFP` = 'Left First-Prone'
  `LFS` = 'Left First-Supine'
  `PFDL` = 'Posterior First-Decubitus Left'
  `PFDR` = 'Posterior First-Decubitus Right'
  `RFP` = 'Right First-Prone'
  `RFS` = 'Right First-Supine'

## django_dicom.reader.code_strings.scanning_sequence module

class `django_dicom.reader.code_strings.scanning_sequence.` `ScanningSequence`

  Bases: `django_dicom.models.choice_enum.ChoiceEnum`

  Represents the Scanning Sequence attribute.

  `EP` = 'Echo Planar'
  `GR` = 'Gradient Recalled'
  `IR` = 'Inversion Recovery'
  `RM` = 'Research Mode'
  `SE` = 'Spin Echo'

## django_dicom.reader.code_strings.sequence_variant module

class `django_dicom.reader.code_strings.sequence_variant.` `SequenceVariant`

  Bases: `django_dicom.models.choice_enum.ChoiceEnum`

  Represents the Sequence Variant attribute.

  `MP` = 'MAG Prepared'
  `MTC` = 'Magnetization Transfer Contrast'
  `NONE` = 'None'
  `OSP` = 'Oversampling Phase'
  `SK` = 'Segmented k-Space'
  `SP` = 'Spoiled'
  `SS` = 'Steady State'
  `TRSS` = 'Time Reversed Steady State'

## django_dicom.reader.code_strings.sex module

class `django_dicom.reader.code_strings.sex.` `Sex`

  Bases: `django_dicom.models.choice_enum.ChoiceEnum`

  Represents the Patient’s Sex attribute.

  `F` = 'Female'
  `M` = 'Male'
  `O` = 'Other'